==> dasu_4.11.jar: edu/northwestern/dasu/measurement/AMCoordinatorV2Interface.java <==
/**
 * Dasu Project
 *
 * File:         AMCoordinatorV2Interface.java
 * RCS:          $Id: AMCoordinatorV2Interface.java,v 1.0 Jul 21, 2012 4:51:48 PM mas939 Exp $
 * Description:  AMCoordinatorV2Interface class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 21, 2012 at 4:51:48 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;

import java.util.ArrayList;
import java.util.Map;

import edu.northwestern.cs.aqualab.Cattle.json.JSONObject;
import edu.northwestern.dasu.measurement.tasks.ProbeTask;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The AMCoordinatorV2Interface class ...
 */
public interface AMCoordinatorV2Interface {
	
	public boolean addProbeTask(ProbeTask pt) throws Exception;
	
	public ArrayList<ArrayList<String>> getMyDnsServers() throws Exception;;
	
	public String getMyPublicIp() throws Exception;
	
	public float getPluginVersion() throws Exception;
		
	public void commitFeedback(String type, String name, String email, String message, String dump) throws Exception;
	
	public void commitReportableFact(String type, Map<String, Object> values) throws Exception;
	
	public JSONObject getJSONObjectFromServer(Integer taskId, String resource) throws Exception;
	
	
//	/*******************
//	 * SessionSamples
//	 *******************/	
//	
//	public Hashtable<String, SessionSignalHolder> getSessionSample();
//
//	public boolean sessionSampleExists(String name);
//
//	public boolean sessionSampleCreate(String name, int size);
//
//	public boolean sessionSampleDestroy(String name); 
//
//	public boolean sessionSampleSetValue(String name, Object value);
//
//	public void sessionSamplePrint(String name);
//
//	public Collection<Object> sessionSampleGetValues(String name);
//
//	public Collection<Long> sessionSampleGetTimeStamps(String name);
//
//	/*******************
//	 * historicSamples
//	 *******************/
//
//	public Hashtable<String, HistoricSignalHolder> getHistoricSample();
//
//	public boolean historicSampleExists(String name);
//	
//	public boolean historicSampleExists(String name, String signalName);
//
//	public boolean historicSampleCreate(String name,
//			TimeType timeSpanType, TimeType intervalType, int intervalLength);
//
//	public boolean historicSampleDestroy(String name);
//
//	public float historicSampleGetValue(String name, String signalName,
//			long timeRecorded);
//
//	public HistoricSignalHolder historicSampleGetSignalHolder(String name);
//
//	public long historicSampleGetTimeStamp(String name, long timeRecorded);
//
//	public long historicSampleGetTimeStamp(String name,
//			String signalName, float value);
//
//	public boolean historicSampleSetValue(String name,
//			String signalName, long timeRecorded, float value, String unit);
//
//	public void historicSamplePrint(String name);
//
//	public Collection<Float> historicSampleGetValues(String name,
//			String signalName);
//
//	public Collection<Long> historicSampleGetTimeStamps(String name);
//
//	public Collection<Float> historicSampleGetValuesSubsetPast(
//			String name, String signalName, long timeRecorded, int numIntervals);
//
//	@Deprecated
//	public Collection<Long> historicSampleGetTimeStampsSubsetPast(
//			String name, String signalName, long timeRecorded, int numIntervals);
//
//	/*******************
//	 * CronJob Scheduler
//	 *******************/
//
//	public void removeCronJob(String id, Integer[] hour, Integer[] day,
//			String commandToExecute);
//	
//	public void removeCronJob(String id, String commandToExecute,
//			CronjobType cronjobType);
//
//	public void addCronJob(String id, Integer[] hour, Integer[] day,
//			String commandToExecute);
//
//	public void addCronJob(String id, String commandToExecute,
//			CronjobType cronjobType);
//
//	/******************/
//
//	public void stopActiveTorrents();
//	
//	public void commitInterference(String type, Long timestamp);
//
//
//	public void commitUserReports(String dids, String comment);
//
//	public void commitIspInfo(String prefix, String ispname);
//
//	public void commitInterferenceEvent(String type, long timestamp, long downloadId, long droppedTo, float mean);
//
//	public String getNewRandomDasuUrl();
//
	

}

==> dasu_5.31.jar: edu/northwestern/dasu/measurement/AMCoordinatorV2Interface.java <==
/**
 * Dasu Project
 *
 * File:         AMCoordinatorV2Interface.java
 * RCS:          $Id: AMCoordinatorV2Interface.java,v 1.0 Jul 21, 2012 4:51:48 PM mas939 Exp $
 * Description:  AMCoordinatorV2Interface class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 21, 2012 at 4:51:48 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;

import java.util.ArrayList;
import java.util.Map;

import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONObject;
import edu.northwestern.dasu.drools.FactFireAction;
import edu.northwestern.dasu.measurement.tasks.ProbeTask;
import edu.northwestern.dasu.timer.TimerEntry;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The AMCoordinatorV2Interface class ...
 */
public interface AMCoordinatorV2Interface {
	
	public boolean addProbeTask(ProbeTask pt) throws Exception;
	
	public ArrayList<ArrayList<String>> getMyDnsServers() throws Exception;;
	
	public String getMyPublicIp() throws Exception;
	
	public float getPluginVersion() throws Exception;
	
	public Map<String, Object> getEnvInfo() throws Exception;
	
	@Deprecated
	public void commitFeedback(String type, String name, String email, String message, String dump) throws Exception;
	
	public void commitReportableFact(String type, Map<String, Object> values) throws Exception;
	
	public JSONObject getJSONObjectFromServer(Integer taskId, String resource) throws Exception;
	
	public boolean addTimerJob(String id, TimerEntry timerEntry, final FactFireAction fireAction) throws Exception;
	
//	/*******************
//	 * SessionSamples
//	 *******************/	
//	
//	public Hashtable<String, SessionSignalHolder> getSessionSample();
//
//	public boolean sessionSampleExists(String name);
//
//	public boolean sessionSampleCreate(String name, int size);
//
//	public boolean sessionSampleDestroy(String name); 
//
//	public boolean sessionSampleSetValue(String name, Object value);
//
//	public void sessionSamplePrint(String name);
//
//	public Collection<Object> sessionSampleGetValues(String name);
//
//	public Collection<Long> sessionSampleGetTimeStamps(String name);
//
//	/*******************
//	 * historicSamples
//	 *******************/
//
//	public Hashtable<String, HistoricSignalHolder> getHistoricSample();
//
//	public boolean historicSampleExists(String name);
//	
//	public boolean historicSampleExists(String name, String signalName);
//
//	public boolean historicSampleCreate(String name,
//			TimeType timeSpanType, TimeType intervalType, int intervalLength);
//
//	public boolean historicSampleDestroy(String name);
//
//	public float historicSampleGetValue(String name, String signalName,
//			long timeRecorded);
//
//	public HistoricSignalHolder historicSampleGetSignalHolder(String name);
//
//	public long historicSampleGetTimeStamp(String name, long timeRecorded);
//
//	public long historicSampleGetTimeStamp(String name,
//			String signalName, float value);
//
//	public boolean historicSampleSetValue(String name,
//			String signalName, long timeRecorded, float value, String unit);
//
//	public void historicSamplePrint(String name);
//
//	public Collection<Float> historicSampleGetValues(String name,
//			String signalName);
//
//	public Collection<Long> historicSampleGetTimeStamps(String name);
//
//	public Collection<Float> historicSampleGetValuesSubsetPast(
//			String name, String signalName, long timeRecorded, int numIntervals);
//
//	@Deprecated
//	public Collection<Long> historicSampleGetTimeStampsSubsetPast(
//			String name, String signalName, long timeRecorded, int numIntervals);
//
//	/*******************
//	 * CronJob Scheduler
//	 *******************/
//
//	public void removeCronJob(String id, Integer[] hour, Integer[] day,
//			String commandToExecute);
//	
//	public void removeCronJob(String id, String commandToExecute,
//			CronjobType cronjobType);
//
//	public void addCronJob(String id, Integer[] hour, Integer[] day,
//			String commandToExecute);
//
//	public void addCronJob(String id, String commandToExecute,
//			CronjobType cronjobType);
//
//	/******************/
//
//	public void stopActiveTorrents();
//	
//	public void commitInterference(String type, Long timestamp);
//
//
//	public void commitUserReports(String dids, String comment);
//
//	public void commitIspInfo(String prefix, String ispname);
//
//	public void commitInterferenceEvent(String type, long timestamp, long downloadId, long droppedTo, float mean);
//
//	public String getNewRandomDasuUrl();
//
	

}
